package gov.usgs.earthquake.nshmp.netcdf;

import static com.google.common.base.Preconditions.checkArgument;

import java.io.IOException;
import java.nio.file.Path;

import gov.usgs.earthquake.nshmp.data.XySequence;
import gov.usgs.earthquake.nshmp.geo.Location;
import gov.usgs.earthquake.nshmp.gmm.NehrpSiteClass;
import gov.usgs.earthquake.nshmp.netcdf.data.BoundingData;
import gov.usgs.earthquake.nshmp.netcdf.data.NetcdfDataGroundMotions;
import gov.usgs.earthquake.nshmp.netcdf.data.StaticData;
import gov.usgs.earthquake.nshmp.netcdf.reader.BoundingReaderGroundMotions;
import gov.usgs.earthquake.nshmp.netcdf.reader.ReaderGroundMotions;

import ucar.nc2.dataset.NetcdfDatasets;

/**
 * NetCDF data for ground motions.
 *
 * @author U.S. Geological Survey
 */
public class NetcdfGroundMotions extends Netcdf<XySequence> {

  public NetcdfGroundMotions(Path netcdfPath) {
    super(netcdfPath);
  }

  @Override
  public BoundingData<XySequence> boundingData(Location site) {
    return new BoundingReaderGroundMotions(this, site).boundingData();
  }

  @Override
  public NetcdfDataGroundMotions netcdfData() {
    return (NetcdfDataGroundMotions) netcdfData;
  }

  @Override
  public StaticData<XySequence> staticData(Location site) {
    return boundingData(site).get(site);
  }

  @Override
  public XySequence staticData(Location site, NehrpSiteClass siteClass) {
    checkArgument(
        netcdfData.siteClasses().contains(siteClass),
        "Site class [" + siteClass + "] not supported");
    return staticData(site).get(siteClass);
  }

  @Override
  ReaderGroundMotions getNetcdfData(Path netcdfPath) {
    try (var ncd = NetcdfDatasets.openDataset(netcdfPath.toString())) {
      var group = ncd.getRootGroup();
      return new ReaderGroundMotions(group);
    } catch (IOException e) {
      throw new RuntimeException("Could not read Netcdf file [" + netcdfPath + " ]");
    }
  }
}
