package gov.usgs.earthquake.nshmp.netcdf.data;

import static com.google.common.base.Preconditions.checkState;

import java.util.Map;

import gov.usgs.earthquake.nshmp.gmm.Imt;

/**
 * NetCDF data for hazard curves.
 *
 * @author U.S. Geological Survey
 */
public class NetcdfDataHazardCurves extends NetcdfData {

  private final Map<Imt, double[]> imls;

  public NetcdfDataHazardCurves(NetcdfData netcdfData, Map<Imt, double[]> imls) {
    super(NetcdfData.Builder.copyOf(netcdfData));
    checkState(!imls.isEmpty(), "Must add imls");
    this.imls = imls;
  }

  /**
   * Returns the Imls
   */
  public Map<Imt, double[]> imls() {
    return imls;
  }

  /**
   * Returns the number of Imls
   */
  public int nIml() {
    return imls.values().iterator().next().length;
  }

  public static Builder builder() {
    return new Builder();
  }
}
