package gov.usgs.earthquake.nshmp.netcdf.data;

import static com.google.common.base.Preconditions.checkState;

import java.util.EnumMap;

import gov.usgs.earthquake.nshmp.data.XySequence;
import gov.usgs.earthquake.nshmp.gmm.Imt;

/**
 * IMT to XySequence mapper.
 *
 * @auther U.S. Geological Survey
 */
public class StaticDataHazardCurves extends EnumMap<Imt, XySequence> {

  public StaticDataHazardCurves() {
    super(Imt.class);
  }

  private StaticDataHazardCurves(EnumMap<Imt, XySequence> staticHazard) {
    super(Imt.class);
    putAll(staticHazard);
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    EnumMap<Imt, XySequence> staticHazard;

    private Builder() {
      staticHazard = new EnumMap<>(Imt.class);
    }

    public Builder put(Imt imt, XySequence xySequence) {
      staticHazard.put(imt, xySequence);
      return this;
    }

    public StaticDataHazardCurves build() {
      checkState(!staticHazard.isEmpty(), "Must add hazards");
      return new StaticDataHazardCurves(staticHazard);
    }
  }
}
