package gov.usgs.earthquake.nshmp.netcdf.data;

import static com.google.common.base.Preconditions.checkState;

import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.Map;

import gov.usgs.earthquake.nshmp.geo.Location;

/**
 * Location to static data mapper.
 *
 * @author U.S. Geological Survey
 */
public class BoundingData<T> extends LinkedHashMap<Location, StaticData<T>> {

  public BoundingData() {}

  private BoundingData(Map<Location, StaticData<T>> boundingHazards) {
    putAll(boundingHazards);
  }

  public static <T> Builder<T> builder() {
    return new Builder<T>();
  }

  public static class Builder<T> {
    Map<Location, StaticData<T>> boundingData;

    private Builder() {
      boundingData = new HashMap<>();
    }

    public Builder<T> put(Location location, StaticData<T> staticData) {
      boundingData.put(location, staticData);
      return this;
    }

    public BoundingData<T> build() {
      checkState(!boundingData.isEmpty(), "Must add static data");
      return new BoundingData<>(boundingData);
    }
  }
}
